@@ -1,10 +1,10 @@
 package DBQuery;
 
-# $Id: DBQuery.pm,v 0.8.0 2010/03/31 12:56:43 Cnangel Exp $
+# $Id: DBQuery.pm,v 1.0.0-0 2010/04/02 14:57:37 Cnangel Exp $
 
 use DBI;
 
-$DBQuery::VERSION = 0.008;
+$DBQuery::VERSION = "1.000";
 
 sub new
 {
@@ -26,6 +26,7 @@ sub new
 		$DB->{driver_name} = 'mysql' unless (defined $DB->{driver_name});
 		$DB->{driver_name} = ucfirst($DB->{driver_name}) if ($DB->{driver_name} eq "oracle");
 		$self = {
+			'driver' => $DB->{driver_name},
 			'dsn' => $DB->{driver_name} eq 'mysql'
 				? 'dbi:' . $DB->{driver_name} . ':database=' . $DB->{db_name} . ';' .
 				(defined $DB->{db_host} ? 'host=' . $DB->{db_host} . ';' : '') .
@@ -40,6 +41,9 @@ sub new
 				  ),
 			'user' => $DB->{db_user},
 			'pass' => (defined $DB->{db_pass} ? $DB->{db_pass} : ''),
+			'pconnect' => $DB->{db_pconnect},
+			'utf8' => $DB->{db_enable_utf8},
+			'autocommit' => (defined $DB->{db_autocommit} ? $DB->{db_autocommit} : 1),
 			'dbh' => undef,
 			'sth' => undef,
 		};
@@ -56,6 +60,12 @@ sub connect
 	} else {
 		$self->{dbh} = DBI->connect($self->{dsn}, $self->{user}, $self->{pass}, {'RaiseError' => 1});
 	}
+
+	if ($DB->{driver_name} eq 'mysql') {
+		$self->{dbh}->{mysql_auto_reconnect} = $self->{pconnect} ? 1 : 0;
+		$self->{dbh}->{mysql_enable_utf8} = $self->{utf8} ? 1 : 0;
+		$self->{dbh}->{mysql_no_autocommit_cmd} = $self->{autocommit} ? 0 : 1;
+	}
 	return;
 }
 
@@ -122,10 +132,13 @@ use DBQuery;
 Init mysql struct example:
 
     my %DB = (
-		'db_host'	=> 'web10.search.cnb.yahoo.com',
-		'db_user'	=> 'yahoo',
-		'db_pass'	=> 'yahoo',
-		'db_name'	=> 'ADCode',
+		'db_host'			=> 'web10.search.cnb.yahoo.com',
+		'db_user'			=> 'yahoo',
+		'db_pass'			=> 'yahoo',
+		'db_name'			=> 'ADCode',
+		'db_pconnect'		=> 1,
+		'db_autocommit'		=> 1,
+		'db_enable_utf8'	=> 0,
 		);
     my $db = new DBQuery(\%DB);
 
@@ -153,7 +166,7 @@ or oracle:
 over this, you can use dsn for init structure.
 
     my %DB = (
-		'dsn'		=> 'dbi:mysql:database=testinter;host=localhost;mysql_socket=/var/lib/mysql/mysql.sock',
+		'dsn'		=> 'dbi:mysql:database=testinter;host=localhost;mysql_socket=/var/lib/mysql/mysql.sock;mysql_use_result=1',
 		'db_user'       => 'pca',
 		'db_pass'       => 'pca',
 		);
